跳到主要内容

ReadError

搜索

枚举 ReadError 

源代码
pub enum ReadError {
    Reset(VarInt),
    ConnectionLost(ConnectionError),
    ClosedStream,
    IllegalOrderedRead,
    ZeroRttRejected,
}
展开描述

从流读取时产生的错误。

变体



Reset(VarInt)

对端放弃在该流上继续发送数据

携带一个由应用层定义的错误码。



ConnectionLost(ConnectionError)

连接已丢失



ClosedStream

该流已经被 stop、finish 或 reset



IllegalOrderedRead

在一次无序读取之后又尝试了一次有序读取

无序读取会在流的接收缓冲区中产生无法恢复的不连续,从而无法再进行有序读取。



ZeroRttRejected

该流为 0-RTT 流,但服务器拒绝了它

仅对客户端的 0-RTT 流可能发生,可通过 Connecting::into_0rtt() 打开 0-RTT 流。

trait 实现

源代码

impl Clone for ReadError

源代码

fn clone(&self) -> ReadError

返回值的副本。 更多信息
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
源代码

impl Debug for ReadError

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl Display for ReadError

源代码

fn fmt(&self, __formatter: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
源代码

impl Error for ReadError

源代码

fn source(&self) -> Option<&(dyn Error + 'static)>

返回此错误的更底层来源(若有)。 更多信息
1.0.0 · 源代码

fn description(&self) -> &str

👎Deprecated since 1.42.0: use the Display impl or to_string()
1.0.0 · 源代码

fn cause(&self) -> Option<&dyn Error>

👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
源代码

fn provide<'a>(&'a self, request: &mut Request<'a>)

🔬This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports. 更多信息
源代码

impl From<ConnectionError> for ReadError

源代码

fn from(source: ConnectionError) -> Self

从输入类型转换为此类型。
源代码

impl From<ReadError> for Error

源代码

fn from(x: ReadError) -> Self

从输入类型转换为此类型。
源代码

impl From<ReadError> for ReadExactError

源代码

fn from(source: ReadError) -> Self

从输入类型转换为此类型。
源代码

impl From<ReadError> for ReadToEndError

源代码

fn from(source: ReadError) -> Self

从输入类型转换为此类型。
源代码

impl From<ReadableError> for ReadError

源代码

fn from(e: ReadableError) -> Self

从输入类型转换为此类型。
源代码

impl From<ResetError> for ReadError

源代码

fn from(e: ResetError) -> Self

从输入类型转换为此类型。
源代码

impl PartialEq for ReadError

源代码

fn eq(&self, other: &ReadError) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl Eq for ReadError

源代码

impl StructuralPartialEq for ReadError

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回该参数。

源代码

impl<T> Instrument for T

源代码

fn instrument(self, span: Span) -> Instrumented<Self>

Instruments this type with the provided Span, returning an Instrumented wrapper. 更多信息
源代码

fn in_current_span(self) -> Instrumented<Self>

Instruments this type with the current Span, returning an Instrumented wrapper. 更多信息
源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换行为完全由 From<T> for U 的实现决定。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

The resulting type after obtaining ownership.
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

Converts the given value to a String. 更多信息
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

The type returned in the event of a conversion error.
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

The type returned in the event of a conversion error.
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。
源代码

impl<V, T> VZip<V> for T
where V: MultiLane<T>,

源代码

fn vzip(self) -> V

源代码

impl<T> WithSubscriber for T

源代码

fn with_subscriber<S>(self, subscriber: S) -> WithDispatch<Self>
where S: Into<Dispatch>,

Attaches the provided Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

fn with_current_subscriber(self) -> WithDispatch<Self>

Attaches the current default Subscriber to this type, returning a WithDispatch wrapper. 更多信息
源代码

impl<ST, DT> CastableFrom<ST, Initialized, Initialized> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<ST, DT> CastableFrom<ST, Uninit, Uninit> for DT
where ST: ?Sized, DT: ?Sized,

源代码

impl<T> Read<Exclusive, BecauseExclusive> for T
where T: ?Sized,